@@ -38,12 +38,8 @@ class FormatterMessage(object):
         text = text_ident + ("\n" + text_ident).join(lines)
         return text
 
-    def message_error_up(self, error):
-        message_error = termcolor.colored(self.message(method="up") + "\n" + str(error), "red")
-        return message_error
-
-    def message_error_down(self, error):
-        message_error = termcolor.colored(self.message(method="down") + "\n" + str(error), "red")
+    def message_error(self, method, error):
+        message_error = termcolor.colored(self.message(method=method) + "\n" + str(error), "red")
         return message_error
 
 
@@ -56,14 +52,8 @@ class TerminalMessages(object):
     def current_version(self):
         print self.migrations.current_version
 
-    def up_message(self, migration):
-        print FormatterMessage(migration).message(method="up")
+    def make_message(self, method, migration):
+        print FormatterMessage(migration).message(method=method)
 
-    def down_message(self, migration):
-        print FormatterMessage(migration).message(method="down")
-
-    def error_message_up(self, migration, error):
-        print FormatterMessage(migration).message_error_up(error)
-
-    def error_message_down(self, migration, error):
-        print FormatterMessage(migration).message_error_down(error)
+    def error_message(self, method, migration, error):
+        print FormatterMessage(migration).message_error(method, error)
